@@ -442,7 +442,7 @@ class Predictor:
                 if self._helper_mixers is not None and output_column in self._helper_mixers:
                     if (self._helper_mixers[output_column]['accuracy'] > 1.00 * self.train_accuracy[output_column]['value']) or CONFIG.FORCE_HELPER_MIXERS:
                         helper_mixer_predictions = self._helper_mixers[output_column]['model'].predict(when_data_ds, [output_column])
-                        
+
                         main_mixer_predictions[output_column] = helper_mixer_predictions[output_column]
 
         return main_mixer_predictions
@@ -507,6 +507,17 @@ class Predictor:
 
             accuracy = self.apply_accuracy_function(ds.get_column_config(output_column)['type'], real, predicted,weight_map=weight_map)
 
+            if ds.get_column_config(output_column)['type'] in (COLUMN_DATA_TYPES.NUMERIC):
+                ds.encoders[output_column].decode_log = True
+                predicted =ds.get_decoded_column_data(output_column, predictions[output_column]['encoded_predictions'])
+
+                alternative_accuracy = self.apply_accuracy_function(ds.get_column_config(output_column)['type'], real, predicted,weight_map=weight_map)
+
+                if alternative_accuracy['value'] > accuracy['value']:
+                    accuracy = alternative_accuracy
+                else:
+                    ds.encoders[output_column].decode_log = False
+
             accuracies[output_column] = accuracy
 
         return accuracies
